@@ -23,19 +23,41 @@
         #+sbcl :sb-mop
         #+lispworks :hcl
         :cl-user
+        :cl-cli
         :Scat.Lib
         ))
 
 (in-package :edu.unm.hpc.Scat.nodels)
 
+(defvar *nodes* ())
+
+(defvar *opts* 
+  (list
+   (make-instance 'cli-opt
+                  :name "help"
+                  :arguments ()
+                  :action
+                  #'(lambda ()
+                      (org.prewett.cl-cli::help *opts*)
+                      (cl-user::quit))
+                  :description "display this help text")
+   (make-instance 'cli-opt
+                  :name :default
+                  :arguments '(noderange)
+                  :action
+                  #'(lambda (noderange)
+                      (setf *nodes* 
+                            (Scat.Lib::expand-nodelist noderange))))))
+
 (defun toplevel () 
   (read-scat-config)
-  (if (equal (length (rest sb-ext:*posix-argv*)) 1)
-      (let* ((nodes 
-              (scat.noderange::expand-nodelist 
-               (car (rest sb-ext:*posix-argv*)))))
-        (Scat.Noderange::print-noderange t nodes)
-        (cl-user::quit))
-      (progn
-        (warn "expected: noderange")
-        (sb-ext::quit))))
\ No newline at end of file
+  (cl-cli::process-options *opts* (rest sb-ext:*posix-argv*))
+
+  (let* ((actual-nodes (Scat.lib::list-node-files))
+         (ls-nodes *nodes*)
+         (intersection (intersection actual-nodes ls-nodes :test #'equal)))
+    (if (eql (length ls-nodes)
+             (length intersection)) ; are all of the requested nodes there?
+        (format t "~{~A~%~}" ls-nodes)
+        (format t "~{~A~%~}" (sort intersection #'string< ))))
+  (cl-user::quit))
\ No newline at end of file
